@@ -1,8 +1,9 @@
 import contextlib
 import logging
 import re
+import warnings
 from dataclasses import replace
-from typing import Any, Dict, List, Optional, Set
+from typing import Any, Awaitable, Dict, List, Optional, Set
 
 import aiodocker
 import aiohttp
@@ -23,7 +24,7 @@ from .core import _Core
 from .errors import AuthorizationError
 from .parser import Parser
 from .parsing_utils import LocalImage, RemoteImage, Tag, TagOption, _as_repo_str
-from .utils import NoPublicConstructor
+from .utils import NoPublicConstructor, aclosing
 
 REPOS_PER_PAGE = 30
 TAGS_PER_PAGE = 30
@@ -100,10 +101,13 @@ class Images(metaclass=NoPublicConstructor):
                 ) from error
         auth = await self._config._docker_auth()
         try:
-            async for obj in self._docker.images.push(repo, auth=auth, stream=True):
-                step = _try_parse_image_progress_step(obj, remote.tag)
-                if step:
-                    progress.step(step)
+            async with aclosing(
+                self._docker.images.push(repo, auth=auth, stream=True)
+            ) as it:
+                async for obj in it:
+                    step = _try_parse_image_progress_step(obj, remote.tag)
+                    if step:
+                        progress.step(step)
         except DockerError as error:
             # TODO check this part when registry fixed
             if error.status == 403:
@@ -139,7 +143,7 @@ class Images(metaclass=NoPublicConstructor):
             headers={"Accept": "application/vnd.docker.distribution.manifest.v2+json"},
         ) as resp:
             data = await resp.json()
-            size = sum([layer["size"] for layer in data["layers"]])
+            size = sum(layer["size"] for layer in data["layers"])
             return Tag(name=remote.tag, size=size)
 
     async def rm(self, remote: RemoteImage, digest: str) -> None:
@@ -165,11 +169,14 @@ class Images(metaclass=NoPublicConstructor):
         repo = _as_repo_str(remote)
         auth = await self._config._docker_auth()
         try:
-            async for obj in self._docker.pull(repo, auth=auth, repo=repo, stream=True):
-                self._temporary_images.add(repo)
-                step = _try_parse_image_progress_step(obj, remote.tag)
-                if step:
-                    progress.step(step)
+            async with aclosing(
+                self._docker.pull(repo, auth=auth, repo=repo, stream=True)
+            ) as it:
+                async for obj in it:
+                    self._temporary_images.add(repo)
+                    step = _try_parse_image_progress_step(obj, remote.tag)
+                    if step:
+                        progress.step(step)
         except DockerError as error:
             if error.status == 404:
                 raise ValueError(
@@ -184,10 +191,13 @@ class Images(metaclass=NoPublicConstructor):
 
         return local
 
-    async def ls(self) -> List[RemoteImage]:
+    async def list(self, cluster_name: Optional[str] = None) -> List[RemoteImage]:
         auth = await self._config._registry_auth()
-        prefix = f"image://{self._config.cluster_name}/"
-        url = self._config.registry_url.with_path("/v2/") / "_catalog"
+        if cluster_name is None:
+            cluster_name = self._config.cluster_name
+        prefix = f"image://{cluster_name}/"
+        url = self._config.get_cluster(cluster_name).registry_url
+        url = url.with_path("/v2/") / "_catalog"
         result: List[RemoteImage] = []
         while True:
             url = url.update_query(n=str(REPOS_PER_PAGE))
@@ -208,6 +218,15 @@ class Images(metaclass=NoPublicConstructor):
                 url = URL(resp.links["next"]["url"])
         return result
 
+    def ls(self, cluster_name: Optional[str] = None) -> Awaitable[List[RemoteImage]]:
+        warnings.warn(
+            "client.images.ls() ls is deprecated and scheduled for removal "
+            "in future Neuro SDK release, please use client.images.list() instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.list(cluster_name=cluster_name)
+
     def _validate_image_for_tags(self, image: RemoteImage) -> None:
         err = f"Invalid image `{image}`: "
         if image.tag is not None:
