@@ -102,11 +102,11 @@ async def mock_for_login_factory(
                     "name": "default",
                     "registry_url": "https://registry-dev.test.com",
                     "storage_url": "https://storage-dev.test.com",
-                    "blob_storage_url": "https://blob-storage-dev.test.com",
                     "users_url": "https://users-dev.test.com",
                     "monitoring_url": "https://monitoring-dev.test.com",
                     "secrets_url": "https://secrets-dev.test.com",
                     "disks_url": "https://disks-dev.test.com",
+                    "buckets_url": "https://buckets-dev.test.com",
                     "resource_presets": [
                         {
                             "name": "gpu-small",
@@ -433,7 +433,7 @@ class TestLogout:
     async def test_logout_no_browser_callback(self, config_dir: Path) -> None:
         await Factory().logout()
         assert not config_dir.exists(), "Config not removed after logout\n" + "\n".join(
-            [p.name for p in config_dir.iterdir()]
+            p.name for p in config_dir.iterdir()
         )
 
     async def test_logout_with_browser_callback(
@@ -447,7 +447,7 @@ class TestLogout:
 
         await Factory().logout(show_browser)
         assert not config_dir.exists(), "Config not removed after logout\n" + "\n".join(
-            [p.name for p in config_dir.iterdir()]
+            p.name for p in config_dir.iterdir()
         )
 
 
